==> jaxb-svg11-1.0.2-sources.jar: org/plutext/jaxb/svg11/SVGAltGlyphDefContent.java <==
/*
 *  Copyright 2010, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.plutext.jaxb.svg11;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SVG.altGlyphDef.content complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SVG.altGlyphDef.content">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice>
 *         &lt;element ref="{http://www.w3.org/2000/svg}glyphRef" maxOccurs="unbounded"/>
 *         &lt;element ref="{http://www.w3.org/2000/svg}altGlyphItem" maxOccurs="unbounded"/>
 *       &lt;/choice>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SVG.altGlyphDef.content", propOrder = {
    "glyphRef",
    "altGlyphItem"
})
public class SVGAltGlyphDefContent {

    protected List<GlyphRef> glyphRef;
    protected List<AltGlyphItem> altGlyphItem;

    /**
     * Gets the value of the glyphRef property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the glyphRef property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getGlyphRef().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link GlyphRef }
     * 
     * 
     */
    public List<GlyphRef> getGlyphRef() {
        if (glyphRef == null) {
            glyphRef = new ArrayList<GlyphRef>();
        }
        return this.glyphRef;
    }

    /**
     * Gets the value of the altGlyphItem property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the altGlyphItem property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAltGlyphItem().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AltGlyphItem }
     * 
     * 
     */
    public List<AltGlyphItem> getAltGlyphItem() {
        if (altGlyphItem == null) {
            altGlyphItem = new ArrayList<AltGlyphItem>();
        }
        return this.altGlyphItem;
    }

}

==> jaxb-svg11-11.4.0-sources.jar: org/plutext/jaxb/svg11/SVGAltGlyphDefContent.java <==
/*
 *  Copyright 2010, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.plutext.jaxb.svg11;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SVG.altGlyphDef.content complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SVG.altGlyphDef.content">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;choice>
 *         &lt;element ref="{http://www.w3.org/2000/svg}glyphRef" maxOccurs="unbounded"/>
 *         &lt;element ref="{http://www.w3.org/2000/svg}altGlyphItem" maxOccurs="unbounded"/>
 *       &lt;/choice>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SVG.altGlyphDef.content", propOrder = {
    "glyphRef",
    "altGlyphItem"
})
public class SVGAltGlyphDefContent {

    protected List<GlyphRef> glyphRef;
    protected List<AltGlyphItem> altGlyphItem;

    /**
     * Gets the value of the glyphRef property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the glyphRef property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getGlyphRef().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link GlyphRef }
     * 
     * 
     */
    public List<GlyphRef> getGlyphRef() {
        if (glyphRef == null) {
            glyphRef = new ArrayList<GlyphRef>();
        }
        return this.glyphRef;
    }

    /**
     * Gets the value of the altGlyphItem property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the altGlyphItem property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAltGlyphItem().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AltGlyphItem }
     * 
     * 
     */
    public List<AltGlyphItem> getAltGlyphItem() {
        if (altGlyphItem == null) {
            altGlyphItem = new ArrayList<AltGlyphItem>();
        }
        return this.altGlyphItem;
    }

}
